@@ -165,6 +165,13 @@ if you prefer to blend Standard and Modus into a single group, enable
     `(magit-section-highlight ((,c :background ,bg-alt)))
     `(magit-diff-file-heading-highlight ((,c :inherit magit-diff-file-heading :background ,bg-alt)))
     `(mode-line
+      ((default :inherit modus-themes-ui-variable-pitch
+                :background ,bg-mode-line-active
+                :foreground ,fg-mode-line-active)
+       (((supports :box t))
+        ,@(modus-themes--box border-mode-line-active nil 'released-button))
+       (t :underline ,border-mode-line-active)))
+    `(mode-line-active
       ((default :inherit modus-themes-ui-variable-pitch
                 :background ,bg-mode-line-active
                 :foreground ,fg-mode-line-active)
